summaryrefslogtreecommitdiffstats
path: root/store/storetest/mocks/EmojiStore.go
diff options
context:
space:
mode:
Diffstat (limited to 'store/storetest/mocks/EmojiStore.go')
-rw-r--r--store/storetest/mocks/EmojiStore.go10
1 files changed, 5 insertions, 5 deletions
diff --git a/store/storetest/mocks/EmojiStore.go b/store/storetest/mocks/EmojiStore.go
index c01e64578..d1bfe7f00 100644
--- a/store/storetest/mocks/EmojiStore.go
+++ b/store/storetest/mocks/EmojiStore.go
@@ -61,13 +61,13 @@ func (_m *EmojiStore) GetByName(name string) store.StoreChannel {
return r0
}
-// GetList provides a mock function with given fields: offset, limit
-func (_m *EmojiStore) GetList(offset int, limit int) store.StoreChannel {
- ret := _m.Called(offset, limit)
+// GetList provides a mock function with given fields: offset, limit, sort
+func (_m *EmojiStore) GetList(offset int, limit int, sort string) store.StoreChannel {
+ ret := _m.Called(offset, limit, sort)
var r0 store.StoreChannel
- if rf, ok := ret.Get(0).(func(int, int) store.StoreChannel); ok {
- r0 = rf(offset, limit)
+ if rf, ok := ret.Get(0).(func(int, int, string) store.StoreChannel); ok {
+ r0 = rf(offset, limit, sort)
} else {
if ret.Get(0) != nil {
r0 = ret.Get(0).(store.StoreChannel)